==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicToolBarSeparatorUI.h <==
// public class javax.swing.plaf.basic.BasicToolBarSeparatorUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 9693afb0713a235 javax_swing_plaf_SeparatorUI
// @dep_class eaf5c562f9f773df javax_swing_plaf_basic_BasicSeparatorUI
// @dep_class e5f737120fa08284 javax_swing_plaf_basic_BasicToolBarSeparatorUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicSeparatorUI

#include "javax/swing/plaf/basic/BasicSeparatorUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarSeparatorUI_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarSeparatorUI_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_JSeparator$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$refs	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtable	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtype	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *);

// Virtual methods
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$getMaximumSize$53a1753c72ad50a1(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$getMinimumSize$0409118567fd57f9(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$getPreferredSize$c70d4f812111358c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *);
extern void _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$installDefaults$5be88efc02d64fbc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JSeparator$object *);
extern void _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$paint$772d1272d1c3f8bb(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_java_awt_Graphics$object *, struct _jc_javax_swing_JComponent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method_info$getMaximumSize$53a1753c72ad50a1;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method_info$getMinimumSize$0409118567fd57f9;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method_info$getPreferredSize$c70d4f812111358c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method_info$installDefaults$5be88efc02d64fbc;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method_info$paint$772d1272d1c3f8bb;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vmethods {
	struct _jc_java_awt_Dimension$object	*(*getMaximumSize$53a1753c72ad50a1)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *);
	struct _jc_java_awt_Dimension$object	*(*getMinimumSize$0409118567fd57f9)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *);
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$c70d4f812111358c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *);
	void	(*installDefaults$5be88efc02d64fbc)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JSeparator$object *);
	void	(*paint$772d1272d1c3f8bb)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_java_awt_Graphics$object *, struct _jc_javax_swing_JComponent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_SeparatorUI$vmethods	javax_swing_plaf_SeparatorUI;
	_jc_javax_swing_plaf_basic_BasicSeparatorUI$vmethods	javax_swing_plaf_basic_BasicSeparatorUI;
	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vmethods	javax_swing_plaf_basic_BasicToolBarSeparatorUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_refs {
	struct _jc_java_awt_Dimension$object	*size;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_refs	javax_swing_plaf_basic_BasicToolBarSeparatorUI;
    _jc_javax_swing_plaf_basic_BasicSeparatorUI$sub_refs	javax_swing_plaf_basic_BasicSeparatorUI;
    _jc_javax_swing_plaf_SeparatorUI$sub_refs	javax_swing_plaf_SeparatorUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_SeparatorUI$sub_nonrefs	javax_swing_plaf_SeparatorUI;
    _jc_javax_swing_plaf_basic_BasicSeparatorUI$sub_nonrefs	javax_swing_plaf_basic_BasicSeparatorUI;
    _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarSeparatorUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object {
	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtype _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarSeparatorUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarSeparatorUI_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicToolBarSeparatorUI.h <==
// public class javax.swing.plaf.basic.BasicToolBarSeparatorUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 9693afb0713a235 javax_swing_plaf_SeparatorUI
// @dep_class eaf5c562f9f773df javax_swing_plaf_basic_BasicSeparatorUI
// @dep_class e5f737120fa08284 javax_swing_plaf_basic_BasicToolBarSeparatorUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicSeparatorUI

#include "javax/swing/plaf/basic/BasicSeparatorUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarSeparatorUI_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarSeparatorUI_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_JSeparator$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$refs	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtable	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtype	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$getMaximumSize$53a1753c72ad50a1(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$getMinimumSize$0409118567fd57f9(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$getPreferredSize$c70d4f812111358c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$installDefaults$5be88efc02d64fbc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JSeparator$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$paint$772d1272d1c3f8bb(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_java_awt_Graphics$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method_info$getMaximumSize$53a1753c72ad50a1;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method_info$getMinimumSize$0409118567fd57f9;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method_info$getPreferredSize$c70d4f812111358c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method_info$installDefaults$5be88efc02d64fbc;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method_info$paint$772d1272d1c3f8bb;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vmethods {
	struct _jc_java_awt_Dimension$object	*(*getMaximumSize$53a1753c72ad50a1)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getMinimumSize$0409118567fd57f9)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$c70d4f812111358c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
	void	(*installDefaults$5be88efc02d64fbc)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_javax_swing_JSeparator$object *) _JC_JCNI_ATTR;
	void	(*paint$772d1272d1c3f8bb)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object *, struct _jc_java_awt_Graphics$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_SeparatorUI$vmethods	javax_swing_plaf_SeparatorUI;
	_jc_javax_swing_plaf_basic_BasicSeparatorUI$vmethods	javax_swing_plaf_basic_BasicSeparatorUI;
	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vmethods	javax_swing_plaf_basic_BasicToolBarSeparatorUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_refs {
	struct _jc_java_awt_Dimension$object	*size;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_refs	javax_swing_plaf_basic_BasicToolBarSeparatorUI;
    _jc_javax_swing_plaf_basic_BasicSeparatorUI$sub_refs	javax_swing_plaf_basic_BasicSeparatorUI;
    _jc_javax_swing_plaf_SeparatorUI$sub_refs	javax_swing_plaf_SeparatorUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_SeparatorUI$sub_nonrefs	javax_swing_plaf_SeparatorUI;
    _jc_javax_swing_plaf_basic_BasicSeparatorUI$sub_nonrefs	javax_swing_plaf_basic_BasicSeparatorUI;
    _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarSeparatorUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$object {
	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$vtype _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarSeparatorUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarSeparatorUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarSeparatorUI_H_ */
